@@ -36,6 +36,7 @@ class ParserBase(type):
 class Parser(object):
     __metaclass__=ParserBase
     name=None
+    css=[] # A list of additional CSSs
     ##
     ## Convert wiki syntax to HTML
     ##
@@ -75,7 +76,11 @@ class Parser(object):
             link=link[11:]
             return u"<a href='/kb/%d/attachment/%s/'>%s</a>"%(kb_entry.id,link,text)
         else:
-            return u"<a href='%s'>%s</a>"%(link,text)
+            try:
+                le=kb_entry.__class__.objects.get(subject=link)
+                return u"<a href='/kb/view/%s/'>%s</a>"%(le.id,text)
+            except kb_entry.__class__.DoesNotExist:
+                return u"<a href='%s'>%s</a>"%(link,text)
     ##
     ## Convert attachment ref
     ##
@@ -84,7 +89,7 @@ class Parser(object):
         if href.startswith("http"):
             return href
         elif href.startswith("attach:"):
-            name=href[7:]
+            href=href[7:]
         elif href.startswith("attachment:"):
             href=href[11:]
         return "/kb/view/%d/attachment/%s/"%(kb_entry.id,href)
