@@ -157,8 +157,8 @@ class Socket(object):
         self.socket=socket
         self.start_time=time.time()
         self.last_read=self.start_time+100
-        self.factory.register_socket(self)
         self.name=None
+        self.factory.register_socket(self)
     ##
     ## Performs actual socket creation
     ##
@@ -446,6 +446,7 @@ class ConnectedTCPSocket(TCPSocket):
     
     def create_socket(self):
         self.socket=socket.socket(socket.AF_INET,socket.SOCK_STREAM)
+        super(ConnectedTCPSocket,self).create_socket()
         if self.local_address:
             self.socket.bind((self.local_address,0))
         e=self.socket.connect_ex((self.address,self.port))
@@ -455,7 +456,6 @@ class ConnectedTCPSocket(TCPSocket):
             return
         elif e not in (0, EISCONN,EINPROGRESS, EALREADY, EWOULDBLOCK):
             raise socket.error, (e, errorcode[e])
-        super(ConnectedTCPSocket,self).create_socket()
         
     def handle_read(self):
         if not self.is_connected:
@@ -585,13 +585,18 @@ class FileWrapper(object):
 class PTYSocket(Socket):
     def __init__(self,factory,argv):
         self.pid=None
-        super(PTYSocket,self).__init__(factory)
         self.argv=argv
         self.out_buffer=""
+        super(PTYSocket,self).__init__(factory)
     
     def create_socket(self):
         self.debug("EXECV(%s)"%str(self.argv))
-        self.pid,fd=pty.fork()
+        try:
+            self.pid,fd=pty.fork()
+        except OSError:
+            self.debug("Cannot get PTY. Closing")
+            self.close()
+            return
         if self.pid==0:
             os.execv(self.argv[0],self.argv)
         else:
@@ -706,6 +711,8 @@ class SocketFactory(object):
             self.sockets.pop(socket.socket.fileno(),None)
             old_name=self.socket_name.pop(socket,None)
             self.name_socket.pop(old_name,None)
+            if socket in self.new_sockets:
+                self.new_sockets.remove(socket)
     ##
     ## Safe call of socket's method
     ## Returns call status (True/False)
@@ -736,6 +743,10 @@ class SocketFactory(object):
             socket.debug("Initializing socket")
             if not self.guarded_socket_call(socket,socket.create_socket):
                 return
+        if socket.socket is None:
+            # Race condition raised. Socket is unregistered since last socket.create_socket call.
+            # Silently ignore and exit
+            return
         with self.register_lock:
             self.sockets[socket.socket.fileno()]=socket
             if socket in self.socket_name:
