@@ -372,6 +372,7 @@ class ScriptTestCase(unittest.TestCase):
     cli=None
     snmp_get={}
     snmp_getnext={}
+    mock_get_version=False # Emulate get_version_call
     
     def test_script(self):
         p=self.script.split(".")
@@ -383,6 +384,12 @@ class ScriptTestCase(unittest.TestCase):
             a.snmp_ro="public"
         # Run script.
         script=script_registry[self.script](profile(),ActivatorStub(self),a,**self.input)
+        # Install mock get_version into cache, if necessary
+        s=self.script.split(".")
+        if self.mock_get_version and s[-1]!="get_version":
+            # Install version info into script call cache
+            version={"vendor": self.vendor, "platform": self.platform, "version": self.version}
+            script.set_cache("%s.%s.get_version"%(s[0],s[1]), {}, version)
         script.run()
         # Parse script result
         if script.result:
