@@ -20,7 +20,7 @@ except ImportError:
 from django.core.management import execute_manager
 
 if __name__ == "__main__":
-    if sys.argv[1] not in ["test","syncdb","migrate"]:
+    if len(sys.argv)>1 and sys.argv[1] not in ["test","syncdb","migrate","debug-script","script-test","topo-test"]:
         # Initialize models
         os.environ["DJANGO_SETTINGS_MODULE"]="noc.settings"
         import noc.urls
