@@ -45,6 +45,9 @@ class Service(SAEService):
                 elif script.e_cancel:
                     e.code=ERR_CANCELLED
                     e.text="Cancelled"
+                elif script.e_not_supported:
+                    e.code=ERR_NOT_SUPPORTED
+                    e.text="Feature is not supported on this platform"
                 elif script.login_error is not None:
                     e.code=ERR_LOGIN_FAILED
                     e.text=script.login_error
@@ -94,7 +97,7 @@ class Service(SAEService):
         kwargs={}
         for a in request.kwargs:
             kwargs[str(a.key)]=cPickle.loads(str(a.value))
-        self.activator.run_script(request.script,request.access_profile,script_callback,**kwargs)
+        self.activator.run_script(request.script,request.access_profile,script_callback,request.timeout,**kwargs)
     
     def ping_check(self,controller,request,done):
         def ping_check_callback(unreachable):
@@ -421,11 +424,14 @@ class Activator(Daemon,FSM):
     ##
     ## Script support
     ##
-    def run_script(self,script_name,access_profile,callback,**kwargs):
-        logging.info("Script %s(%s)"%(script_name,access_profile.address))
+    def run_script(self,script_name,access_profile,callback,timeout,**kwargs):
         pv,pos,sn=script_name.split(".",2)
         profile=profile_registry["%s.%s"%(pv,pos)]()
-        script=script_registry[script_name](profile,self,access_profile,**kwargs)
+        script_class=script_registry[script_name]
+        if not timeout:
+            timeout=script_class.TIMEOUT
+        script=script_class(profile,self,access_profile,timeout,**kwargs)
+        logging.info("Script %s(%s). Timeout set to %s"%(script_name,access_profile.address,timeout))
         with self.script_lock:
             self.script_threads[script]=callback
             logging.info("%d script threads (%d max)"%(len(self.script_threads),self.max_script_threads))
@@ -734,7 +740,7 @@ class Activator(Daemon,FSM):
     ##
     @check_state("ESTABLISHED")
     def cancel_stale_scripts(self):
-        to_cancel=[st for st in self.script_threads.keys() if st.is_stale()]
+        to_cancel=[st for st in self.script_threads.keys() if st.is_stale() and not st.e_cancel]
         for script in to_cancel:
             logging.info("Canceling stale script %s(%s)"%(script.name,script.access_profile.address))
             script.cancel_script()
