@@ -106,6 +106,11 @@ class ManagedObject(models.Model):
     # CM
     is_configuration_managed=models.BooleanField(_("Is Configuration Managed?"),default=True)
     repo_path=models.CharField(_("Repo Path"),max_length=128,blank=True,null=True)
+    # pyRules
+    config_filter_rule=models.ForeignKey(PyRule, verbose_name="Config Filter pyRule", 
+            limit_choices_to={"interface": "IConfigFilter"}, null=True, blank=True, related_name="managed_object_config_filter_rule_set")
+    config_validation_rule=models.ForeignKey(PyRule, verbose_name="Config Validation pyRule",
+            limit_choices_to={"interface": "IConfigValidator"}, null=True, blank=True, related_name="managed_object_config_validation_rule_set")
     #
     tags=AutoCompleteTagsField(_("Tags"),null=True,blank=True)
     
@@ -571,8 +576,12 @@ class ReduceTask(models.Model):
         # Run map task for each object
         for o in objects:
             for ms,p in msp:
-                # Set status to "F" if script not found
-                status="W" if ms in o.profile.scripts else "F"
+                try:
+                    # Set status to "F" if script not found
+                    status="W" if ms in o.profile.scripts else "F"
+                except KeyError:
+                    # Invalid profile
+                    continue
                 # Build full map script name
                 msn="%s.%s"%(o.profile_name,ms)
                 #
