@@ -19,4 +19,5 @@ class Profile(noc.sa.profiles.Profile):
     command_more=" "
     command_leave_config="apply"
     command_save_config="save\ny\n"
-    config_volatile=["^/\* Configuration dump taken"]
+    config_volatile=[r"^/\* Configuration dump taken.*?$"]
+    rogue_chars=["\x08"]
