@@ -2,26 +2,35 @@
 ##----------------------------------------------------------------------
 ## Service Activation Engine Daemon
 ##----------------------------------------------------------------------
-## Copyright (C) 2007-2009 The NOC Project
+## Copyright (C) 2007-2011 The NOC Project
 ## See LICENSE for details
 ##----------------------------------------------------------------------
 """
 """
+## Python modules
 from __future__ import with_statement
+import os
+import time
+import datetime
+import threading
+import logging
+import random
+import cPickle
+## Django modules
+from django.db import reset_queries
+## NOC modules
 from noc.sa.models import Activator, ManagedObject, TaskSchedule, MapTask, periodic_registry, script_registry, profile_registry
-from noc.fm.models import Event,EventData,EventPriority,EventClass,EventCategory,IgnoreEventRules
-from noc.sa.rpc import RPCSocket,file_hash,get_digest,get_nonce
+from noc.fm.models import Event, EventData, EventPriority, EventClass, EventCategory, IgnoreEventRules
+from noc.sa.rpc import RPCSocket, file_hash, get_digest, get_nonce
 from noc.pm.models import TimeSeries
-import logging,time,threading,datetime,os,random,cPickle
 from noc.sa.protocols.sae_pb2 import *
 from noc.lib.fileutils import read_file
 from noc.lib.daemon import Daemon
-from noc.lib.debug import error_report,DEBUG_CTX_CRASH_PREFIX
-from noc.lib.nbsocket import ListenTCPSocket,AcceptedTCPSocket,AcceptedTCPSSLSocket,SocketFactory,Protocol,HAS_SSL
-from django.db import reset_queries
+from noc.lib.debug import error_report, DEBUG_CTX_CRASH_PREFIX
+from noc.lib.nbsocket import ListenTCPSocket, AcceptedTCPSocket, AcceptedTCPSSLSocket, SocketFactory, Protocol, HAS_SSL
 
 ##
-## Additions to MANIFEST-ACTIVATOR file
+## Additions to MANIFEST-ACTIVATfOR file
 ##
 ACTIVATOR_MANIFEST=[
     "sa/profiles/",
@@ -335,7 +344,7 @@ class SAE(Daemon):
             # Check Map/Reduce task status
             self.process_mrtasks()
             self.last_mrtask_check=t
-        
+    
     ##
     ## Write event.
     ## data is a list of (left,right)
@@ -402,14 +411,14 @@ class SAE(Daemon):
     ## events with completion status
     ##
     def periodic_wrapper(self,task):
-        logging.info(u"Executing %s"%unicode(task))
+        logging.info(u"Periodic task=%s status=running"%unicode(task))
         cwd=os.getcwd()
         try:
-            status=task.periodic_class(self).execute()
+            status=task.periodic_class(sae=self, timeout=task.timeout).execute()
         except:
             error_report()
             status=False
-        logging.info(u"Task %s is terminated with '%s'"%(unicode(task),status))
+        logging.info(u"Periodic task=%s status=%s"%(unicode(task),"completed" if status else "failed"))
         if status:
             timeout=task.run_every
         else:
@@ -542,19 +551,34 @@ class SAE(Daemon):
         for a in addresses:
             r.addresses.append(a)
         stream.proxy.ping_check(r,ping_check_callback)
+
+    ##
+    ## Map/Reduce task logging
+    ##
+    def log_mrt(self, level, task, status, args=None, **kwargs):
+        r=[u"MRT task=%d/%d object=%s(%s) script=%s status=%s"%(task.task.id, task.id, task.managed_object.name,
+            task.managed_object.address, task.map_script, status)]
+        if args:
+            a=repr(args)
+            if level<=logging.INFO and len(a)>45:
+                a=a[:20]+u" ... "+a[-20:]
+            r+=[u"args=%s"%a]
+        if kwargs:
+            for k in kwargs:
+                r+=[u"%s=%s"%(k, kwargs[k])]
+        logging.log(level, u" ".join(r))
+        
     ##
     ## Process Map/Reduce tasks
     ##
     def process_mrtasks(self):
         def map_callback(mt_id,result=None,error=None):
-            logging.debug("Map task completed: %d"%mt_id)
             try:
                 mt=MapTask.objects.get(id=mt_id)
             except MapTask.DoesNotExist:
                 logging.error("Map task %d suddently disappeared",mt_id)
                 return
             if error:
-                logging.error("Map Task error: %s"%error.text)
                 # Process non-fatal reasons
                 TIMEOUTS={
                     ERR_ACTIVATOR_NOT_AVAILABLE: 10,
@@ -571,7 +595,7 @@ class SAE(Daemon):
                     else:
                         next_retries=mt.retries_left-1
                     if mt.retries_left and next_try<mt.task.stop_time: # Check we're still in task time and have retries left
-                        logging.debug("Retry task: %d"%mt_id)
+                        self.log_mrt(logging.INFO, task=mt, status="retry")
                         mt.next_try=next_try
                         mt.retries_left=next_retries
                         mt.status="W"
@@ -579,15 +603,18 @@ class SAE(Daemon):
                         return
                 mt.status="F"
                 mt.script_result=dict(code=error.code,text=error.text)
+                self.log_mrt(logging.INFO, task=mt, status="failed", code=error.code, error=error.text)
             else:
                 mt.status="C"
                 mt.script_result=result
+                self.log_mrt(logging.INFO, task=mt, status="completed")
             mt.save()
         # Additional stack frame to store mt_id in a closure
         def exec_script(mt):
             kwargs={}
             if mt.script_params:
                 kwargs=mt.script_params
+            self.log_mrt(logging.INFO, task=mt, status="running", args=kwargs)
             self.script(mt.managed_object,mt.map_script,
                     lambda result=None,error=None: map_callback(mt.id,result,error),
                     **kwargs)
@@ -597,6 +624,7 @@ class SAE(Daemon):
                 mt.status="F"
                 mt.script_result=dict(code=ERR_TIMEOUT, text="Timed out")
                 mt.save()
+                self.log_mrt(logging.INFO, task=mt, status="failed", msg="timed out")
                 continue
             mt.status="R"
             mt.save()
