@@ -200,11 +200,12 @@ class Script(threading.Thread):
     #
     _execute_chain=[]
     
-    def __init__(self,profile,activator,access_profile,parent=None,**kwargs):
+    def __init__(self,profile,activator,access_profile,timeout=0,parent=None,**kwargs):
         self.start_time=time.time()
         self.parent=parent
         self.access_profile=access_profile
         self.attrs={}
+        self._timeout=timeout if timeout else self.TIMEOUT
         for a in access_profile.attrs:
             self.attrs[a.key]=a.value
         import logging
@@ -240,6 +241,7 @@ class Script(threading.Thread):
         self.is_cancelable=False # Can script be cancelled
         self.e_timeout=False # Script terminated with timeout
         self.e_cancel=False # Scrcipt cancelled
+        self.e_not_supported=False # NotSupportedError risen
         self._thread_id=None # Python 2.5 compatibility
         
         if self.parent:
@@ -256,20 +258,12 @@ class Script(threading.Thread):
             self.cli_debug("IP: %s SCRIPT: %s"%(self.access_profile.address,self.name),"!")
     
     ##
-    ## execute method decorator
+    ## Compile arguments into version check function
+    ## Returns callable acception self and version hash arguments
     ##
     @classmethod
-    def match(cls, *args, **kwargs):
-        def decorate(f):
-            global _execute_chain
-            # Append to the execute chain
-            _execute_chain+=[(x, f)]
-            return f
-        
-        # Compile check function
-        c=[]
-        if args:
-            c+=args
+    def compile_match_filter(cls, *args, **kwargs):
+        c=[lambda self, x, g=f: g(x) for f in args]
         for k,v in kwargs.items():
             # Split to field name and lookup operator
             if "__" in k:
@@ -282,47 +276,66 @@ class Script(threading.Thread):
                 raise Exception("Invalid field '%s'"%f)
             # Compile lookup functions
             if o=="exact":
-                c+=[lambda x,f=f,v=v: x[f]==v]
+                c+=[lambda self,x,f=f,v=v: x[f]==v]
             elif o=="iexact":
-                c+=[lambda x,f=f,v=v: x[f].lower()==v.lower()]
+                c+=[lambda self,x,f=f,v=v: x[f].lower()==v.lower()]
             elif o=="startswith":
-                c+=[lambda x,f=f,v=v: x[f].startswith(v)]
+                c+=[lambda self,x,f=f,v=v: x[f].startswith(v)]
             elif o=="istartswith":
-                c+=[lambda x,f=f,v=v: x[f].lower().startswith(v.lower())]
+                c+=[lambda self,x,f=f,v=v: x[f].lower().startswith(v.lower())]
             elif o=="endswith":
-                c+=[lambda x,f=f,v=v: x[f].endswith(v)]
+                c+=[lambda self,x,f=f,v=v: x[f].endswith(v)]
             elif o=="iendswith":
-                c+=[lambda x,f=f,v=v: x[f].lower().endswith(v.lower())]
+                c+=[lambda self,x,f=f,v=v: x[f].lower().endswith(v.lower())]
             elif o=="contains":
-                c+=[lambda x,f=f,v=v: v in x[f]]
+                c+=[lambda self,x,f=f,v=v: v in x[f]]
             elif o=="icontains":
-                c+=[lambda x,f=f,v=v: v.lower() in x[f].lower()]
+                c+=[lambda self,x,f=f,v=v: v.lower() in x[f].lower()]
             elif o=="in":
-                c+=[lambda x,f=f,v=v: x[f] in v]
+                c+=[lambda self,x,f=f,v=v: x[f] in v]
             elif o=="regex":
-                c+=[lambda x,f=f,v=re.compile(v): v.search(x[f]) is not None]
+                c+=[lambda self,x,f=f,v=re.compile(v): v.search(x[f]) is not None]
             elif o=="iregex":
-                c+=[lambda x,f=f,v=re.compile(v, re.IGNORECASE): v.search(x[f]) is not None]
+                c+=[lambda self,x,f=f,v=re.compile(v, re.IGNORECASE): v.search(x[f]) is not None]
             elif o=="isempty": # Empty string or null
-                c+=[lambda x,f=f,v=v: not x[f] if v else x[f]]
+                c+=[lambda self,x,f=f,v=v: not x[f] if v else x[f]]
             elif f=="version":
                 if o=="lt": # <
-                    c+=[lambda x,f=v,v=v,p=self.profile: p.cmp_version(x[v],v)<0 ]
+                    c+=[lambda self,x,v=v: self.profile.cmp_version(x["version"],v)<0 ]
                 elif o=="lte": # <=
-                    c+=[lambda x,f=v,v=v,p=self.profile: p.cmp_version(x[v],v)<=0 ]
+                    c+=[lambda self,x,v=v: self.profile.cmp_version(x["version"],v)<=0 ]
                 elif o=="gt": # >
-                    c+=[lambda x,f=v,v=v,p=self.profile: p.cmp_version(x[v],v)>0 ]
+                    c+=[lambda self,x,v=v: self.profile.cmp_version(x["version"],v)>0 ]
                 elif o=="gte": # >=
-                    c+=[lambda x,f=v,v=v,p=self.profile: p.cmp_version(x[v],v)>=0 ]
+                    c+=[lambda self,x,v=v: self.profile.cmp_version(x["version"],v)>=0 ]
                 else:
                     raise Exception("Invalid lookup operation: %s"%o)
             else:
                 raise Exception("Invalid lookup operation: %s"%o)
         # Combine expressions into single lambda
-        x=reduce(lambda x,y: lambda v,x=x,y=y: x(v) and y(v), c, lambda x: True)
+        return reduce(lambda x,y: lambda self,v,x=x,y=y: x(self,v) and y(self,v), c, lambda self,x: True)
+    
+    ##
+    ## execute method decorator
+    ##
+    @classmethod
+    def match(cls, *args, **kwargs):
+        def decorate(f):
+            global _execute_chain
+            # Append to the execute chain
+            _execute_chain+=[(x, f)]
+            return f
+        # Compile check function
+        x=cls.compile_match_filter(*args, **kwargs)
         # Return decorated function
         return decorate
     
+    ##
+    ## inline version for Script.match
+    ##
+    def match_version(self, *args, **kwargs):
+        return self.compile_match_filter(*args, **kwargs)(self, self.scripts.get_version())
+    
     ##
     ##
     ##
@@ -340,7 +353,7 @@ class Script(threading.Thread):
     ## Checks script is stale and must be terminated
     ##
     def is_stale(self):
-        return time.time()-self.start_time > self.TIMEOUT
+        return time.time()-self.start_time > self._timeout
     
     @classmethod
     def implements_interface(cls,interface):
@@ -373,26 +386,29 @@ class Script(threading.Thread):
         return s.call_cache[repr(key1)][repr(key2)]
     
     ##
-    ## Set cacked result
+    ## Set cached result
     ##
     def set_cache(self,key1,key2,value):
         key1=repr(key1)
         key2=repr(key2)
         s=self.root
-        if key1 not in self.call_cache:
-            self.call_cache[key1]={}
-        self.call_cache[key2]=value
+        if key1 not in s.call_cache:
+            s.call_cache[key1]={}
+        s.call_cache[key1][key2]=value
     
     def guarded_run(self):
-        self.debug("Guarded run")
         # Enforce interface type checking
         for i in self.implements:
             self.kwargs=i.script_clean_input(self.profile,**self.kwargs)
+        self.debug("Running script: %s (%s)"%(self.name, self.kwargs))
         # Use cached result when available
         if self.cache and self.parent is not None:
             try:
-                return self.get_cache(self.name,self.kwargs)
+                result=self.get_cache(self.name,self.kwargs)
+                self.debug("Script returns with cached result: %s"%result)
+                return result
             except KeyError:
+                self.debug("Not in call cache: %s, %s"%(self.name,self.kwargs))
                 pass
         # Calling script body
         self._thread_id=thread.get_ident()
@@ -402,6 +418,7 @@ class Script(threading.Thread):
             result=i.script_clean_result(self.profile,result)
         # Cache result when required
         if self.cache and self.parent is not None:
+            self.debug("Write to call cache: %s, %s, %s"%(self.name,self.kwargs,result))
             self.set_cache(self.name,self.kwargs,result)
         self.debug("Script returns with result: %s"%result)
         return result
@@ -425,15 +442,21 @@ class Script(threading.Thread):
         except CancelledError:
             self.error("Cancelled")
             self.e_cancel=True
+        except self.NotSupportedError:
+            self.e_not_supported=True
         except self.LoginError,why:
             self.login_error=why.args[0]
             self.error("Login failed: %s"%self.login_error)
         except:
-            t,v,tb=sys.exc_info()
-            r=[str(t),str(v)]
-            r+=[format_frames(get_traceback_frames(tb))]
-            self.error_traceback="\n".join(r)
-            self.debug("Script traceback:\n%s"%self.error_traceback)
+            if self.e_cancel:
+                # Race condition caught. Handle CancelledError
+                self.error("Cancelled")
+            else:
+                t,v,tb=sys.exc_info()
+                r=[str(t),str(v)]
+                r+=[format_frames(get_traceback_frames(tb))]
+                self.error_traceback="\n".join(r)
+                self.debug("Script traceback:\n%s"%self.error_traceback)
         self.debug("Closing")
         if self.activator.to_save_output and result:
             self.activator.save_result(result,self.motd)
@@ -452,8 +475,8 @@ class Script(threading.Thread):
             # Get version information
             v=self.scripts.get_version()
             # Find and execute proper handler
-            for c,f in self._execute_chain:
-                if c(v):
+            for c, f in self._execute_chain:
+                if c(self, v):
                     return f(self, **kwargs)
             # Raise error 
             raise NotSupportedError()
@@ -589,11 +612,12 @@ class Script(threading.Thread):
             return
         if not self.isAlive():
             self.error("Trying to kill already dead thread")
-            return self.activator.on_script_exit(self)
+            return
         if not self._thread_id:
             self.error("Cannot cancel the script without thread_id")
             return
         # Raise CancelledError in script's thread
+        self.e_cancel=True
         r=ctypes.pythonapi.PyThreadState_SetAsyncExc(ctypes.c_long(self._thread_id), ctypes.py_object(CancelledError))
         if r==1:
             self.debug("Cancel event sent")
@@ -730,13 +754,22 @@ class CLI(StreamFSM):
             "PROMPT"              : "PROMPT",
             "PAGER"               : "PASSWORD",
         },
+        "SUPER_USERNAME" : {
+            "USERNAME"            : "FAILURE",
+            "UNPRIVELEGED_PROMPT" : "FAILURE",
+            "PASSWORD"            : "SUPER_PASSWORD",
+            "PROMPT"              : "PROMPT",
+            "PAGER"               : "SUPER_USERNAME"
+        },
         "SUPER_PASSWORD" : {
             "UNPRIVELEGED_PROMPT" : "FAILURE",
+            "USERNAME"            : "FAILURE",
             "PASSWORD"            : "FAILURE",
             "PROMPT"              : "PROMPT",
             "PAGER"               : "SUPER_PASSWORD"
         },
         "UNPRIVELEGED_PROMPT":{
+            "USERNAME"            : "SUPER_USERNAME",
             "PASSWORD"            : "SUPER_PASSWORD",
             "PROMPT"              : "PROMPT",
         },
@@ -825,10 +858,11 @@ class CLI(StreamFSM):
         
     def on_PASSWORD_enter(self):
         self.motd="" # Reset MoTD
-        p=[(self.profile.pattern_prompt, "PROMPT")]
+        p=[]
         if self.profile.pattern_unpriveleged_prompt:
             p+=[(self.profile.pattern_unpriveleged_prompt,"UNPRIVELEGED_PROMPT")]
         p+=[
+            (self.profile.pattern_prompt,   "PROMPT"),
             (self.profile.pattern_username, "USERNAME"),
             (self.profile.pattern_password, "PASSWORD")
             ]
@@ -838,11 +872,21 @@ class CLI(StreamFSM):
         
     def on_UNPRIVELEGED_PROMPT_enter(self):
         self.set_patterns([
+            (self.profile.pattern_username, "USERNAME"),
             (self.profile.pattern_prompt,   "PROMPT"),
             (self.profile.pattern_password, "PASSWORD")
         ])
         self.submit(self.profile.command_super)
     
+    def on_SUPER_USERNAME_enter(self):
+        self.set_patterns([
+            (self.profile.pattern_username, "USERNAME"),
+            (self.profile.pattern_prompt,   "PROMPT"),
+            (self.profile.pattern_password, "PASSWORD"),
+            (self.pager_patterns,"PAGER")
+        ])
+        self.submit(self.access_profile.user)
+    
     def on_SUPER_PASSWORD_enter(self):
         self.set_patterns([
             (self.profile.pattern_prompt, "PROMPT"),
